Skip to contents

An sf polygon data frame with FIA state, unit, and county codes and names.

Usage

stunitco

Format

An object of class sf inheriting from data.frame, with 3,108 rows and 8 columns:

STATECD

FIA state code.

STATENM

State name.

UNITCD

FIA unit code.

UNITNM

FIA unit name.

COUNTYCD

County code.

COUNTYNM

County name.

COUNTYFIPS

County FIPS code.

geom

Multipolygon geometry.

The package copy is stored in NAD83 / Conus Albers, EPSG:5070.

Downloaded from the United States Census Bureau on 2019 November 3, originally in Esri Shapefile format from https://www.census.gov/geographies/mapping-files/time-series/geo/carto-boundary-file.html. The original projection was Geographic Coordinate System North American 1983, EPSG:4269. The package copy is projected to EPSG:5070 and omits a small number of very remote island polygons from the original source layer.

See also

Examples

data(stunitco)
nrow(stunitco)
#> [1] 3108
names(stunitco)
#> [1] "STATECD"    "STATENM"    "UNITCD"     "UNITNM"     "COUNTYCD"  
#> [6] "COUNTYNM"   "COUNTYFIPS" "geom"