FIA state, unit, and county polygons
stunitco.RdAn sf polygon data frame with FIA state, unit, and county codes and
names.
Format
An object of class sf inheriting from data.frame, with 3,108 rows
and 8 columns:
STATECDFIA state code.
STATENMState name.
UNITCDFIA unit code.
UNITNMFIA unit name.
COUNTYCDCounty code.
COUNTYNMCounty name.
COUNTYFIPSCounty FIPS code.
geomMultipolygon geometry.
The package copy is stored in NAD83 / Conus Albers, EPSG:5070.
Downloaded from the United States Census Bureau on 2019 November 3, originally in Esri Shapefile format from https://www.census.gov/geographies/mapping-files/time-series/geo/carto-boundary-file.html. The original projection was Geographic Coordinate System North American 1983, EPSG:4269. The package copy is projected to EPSG:5070 and omits a small number of very remote island polygons from the original source layer.